#!/bin/bash

# Grab config from the local bootdeb script
MNT="$(sed -n 's/^MNT=//p' $(dirname $0)/bootdeb)"
IMG="$(sed -n 's/^IMG=//p' $(dirname $0)/bootdeb)"

SU=$(adb shell ls /system/bin/su|sed 's/\r//')
test -n "$SU" || {
  echo "No adb, mobile phone not USB-connected in debug mode, or no su command on the mobile phone." >&2
  echo
  echo "You may need to root your phone first, see e.g. http://blog.heiko-schwarz.com/2009/08/das-rooten-meines-samsung-galaxy.html" >&2
  exit 1
}

# The bootdeb script uses '$EXTERNAL_STORAGE' which is from the phone's environment
MOUNT=$(adb shell echo "${IMG%%/*}"|sed 's/\r//')
adb shell mount|grep -q " $MOUNT vfat " || {
  echo "SD card not mounted." >&2
  exit 1
}

LSIMG=$(adb shell "ls $IMG 2>&-"|sed 's/\r//')
if [ -n "$LSIMG" ]
then
  echo "$LSIMG already exists on the phone. This script does not overwrite..." >&2
else
  echo "adb push $(dirname $0)/${IMG##*/} $IMG"
fi

echo
echo "Preparing /data/local/bin for writing. You may need to press [Allow] on the phone."

adb shell $SU -c "
ls /data/local/mnt/ >&- 2>&- || mkdir /data/local/mnt/;
ls /data/local/bin/ >&- 2>&- || mkdir /data/local/bin/;
chmod 777 /data/local/bin/"

adb push $(dirname $0)/deb /data/local/bin/
for i in bootdeb busybox tun.ko unionfs.ko
do
  adb push $(dirname $0)/$i /data/local/bin/
done

echo
echo "Adding 'deb' and 'ash' commands to /system/bin. You may need to press [Allow] on the phone."

adb shell $SU -c "
/data/local/bin/busybox mount /system -o remount,rw;
chmod 755 /data/local/mnt/ /data/local/bin/ /data/local/bin/deb /data/local/bin/bootdeb /data/local/bin/busybox;
ls /system/bin/deb 2>&- || ln -s /data/local/bin/deb /system/bin/deb;
ls /system/bin/ash 2>&- || ln -s /data/local/bin/busybox /system/bin/ash;
/data/local/bin/busybox mount /system -o remount,ro"

echo "Done. Next step: enter 'deb' on the phone (e.g. in ConnectBox=local)"
