#!/bin/bash -x

IMG="$(sed -n 's/^IMG=//p' $(dirname $0)/bootdeb)"

LOC=$(dirname $0)/${IMG##*/}
TMP=$(dirname $0)/debian-tmp

if [ -z "$1" ] || [ "$1" -lt 512 ]
then
  echo "You need to specify loop disk file size in Megabyte (>= 512)" >&2
  exit 1
fi

if test -e $TMP
then
  echo "$TMP exists. Please remove it before running this script." >&2
  exit 1
fi

if test -e $LOC
then
  echo -n "$LOC exists. Do you want to overwrite? (y/N) " >&2
  read n
  if [ -z "$n" ] || [ "y" != "$n" ] && [ "Y" != "$n" ]
  then
    exit 1
  fi
fi

echo "Creating $LOC, size is $1 Mb..."
dd if=/dev/zero of=$LOC bs=1048576 count=$1

# Note: Std Inodes is too small for hdd 512...1536, because debian has a lot of small files.
mke2fs -i 12288 -F $LOC

# Note: You will forget to unmount often ;-) In that case the 'bootdeb' script will check...
tune2fs -c 0 $LOC

term() {
  echo "Script terminates. Unmounting and removing $TMP" >&2
  sudo umount $TMP
  rmdir $TMP
}

trap term SIGINT SIGTERM
mkdir $TMP
sudo mount -o loop $LOC $TMP

ALGO=gzip
test -n "$(which lzma 2>&1)" && ALGO=lzma

if [ ! -f $TMP.tar.lzma ]
then
  sudo apt-get install debootstrap
  sudo debootstrap --verbose --arch armel --foreign lenny $TMP http://ftp.de.debian.org/debian

  # Note: We save the grabbed image data in case you want to restart later without downloading...
  echo "Creating backup in $TMP.tar.$ALGO..."
  sudo tar --$ALGO -C $TMP -cf $TMP.tar.$ALGO .
  sudo chown $(id -u):$(id -g) $TMP.tar.$ALGO
else
  echo "Extracting backup from $TMP.tar.$ALGO..."
  sudo tar --$ALGO -C $TMP -xf $TMP.tar.$ALGO
fi

sudo umount $TMP
rmdir $TMP
echo "Done."
